@@ -6,11 +6,11 @@ dir.create(subdir)
 test_that("watcher() logs", {
   w <- watcher(dir, callback = NULL)
   expect_s3_class(w, "Watcher")
-  expect_false(w$running)
+  expect_false(w$is_running())
   expect_false(w$stop())
   expect_true(w$start())
-  expect_true(w$running)
-  expect_type(w$path, "character")
+  expect_true(w$is_running())
+  expect_type(w$get_path(), "character")
   Sys.sleep(1)
   file.create(file.path(dir, "testfile"))
   file.remove(file.path(dir, "testfile"))
@@ -18,7 +18,7 @@ test_that("watcher() logs", {
   expect_false(w$start())
   expect_true(w$stop())
   expect_false(w$stop())
-  expect_false(w$running)
+  expect_false(w$is_running())
   rm(w)
 })
 
@@ -27,9 +27,10 @@ test_that("watcher() callbacks", {
   w <- watcher(dir, callback = ~{is.character(.x) || stop(); x <<- x + 1L}, latency = 0.2)
   expect_output(print(w))
   expect_s3_class(w, "Watcher")
-  expect_false(w$running)
+  expect_false(w$is_running())
   expect_true(w$start())
-  expect_true(w$running)
+  expect_true(w$is_running())
+  expect_type(w$get_path(), "character")
   Sys.sleep(1)
   file.create(file.path(subdir, "testfile"))
   later::run_now(1)
@@ -51,7 +52,7 @@ test_that("watcher() callbacks", {
   later::run_now(1)
   expect_gte(x, 1L)
   expect_true(w$stop())
-  expect_false(w$running)
+  expect_false(w$is_running())
   rm(w)
 })
 
